@@ -14,8 +14,6 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import json
-
 from django.contrib import messages
 from django.core.paginator import Paginator, EmptyPage
 from django.core.urlresolvers import reverse_lazy, reverse  # noqa
@@ -25,14 +23,19 @@ from django.views.generic import TemplateView  # noqa
 from horizon import exceptions
 from horizon import forms
 from horizon import tables
+from horizon.utils import functions as utils
+from horizon import workflows
 
 import monascaclient.exc as exc
 from monitoring.alarmdefs import constants
 from monitoring.alarmdefs import forms as alarm_forms
 from monitoring.alarmdefs import tables as alarm_tables
+from monitoring.alarmdefs import workflows as alarm_workflows
 from monitoring import api
 
-LIMIT = 10
+from openstack_dashboard import policy
+
+
 PREV_PAGE_LIMIT = 100
 
 
@@ -45,9 +48,10 @@ class IndexView(tables.DataTableView):
         results = []
         if page_offset is None:
             page_offset = 0
+        limit = utils.get_page_size(self.request)    
         try:
-            results = api.monitor.alarmdef_list(self.request, page_offset, LIMIT)
-            paginator = Paginator(results, LIMIT)
+            results = api.monitor.alarmdef_list(self.request, page_offset, limit)
+            paginator = Paginator(results, limit)
             results = paginator.page(1)
         except EmptyPage:
             contacts = paginator.page(paginator.num_pages)
@@ -57,6 +61,8 @@ class IndexView(tables.DataTableView):
         return results
 
     def get_context_data(self, **kwargs):
+        if not policy.check((('monitoring', 'monitoring:monitoring'), ), self.request):
+            raise exceptions.NotAuthorized()
         context = super(IndexView, self).get_context_data(**kwargs)
         num_results = 0
         contacts = []
@@ -72,12 +78,13 @@ class IndexView(tables.DataTableView):
         else:
             page_offset = int(page_offset)
 
+        limit = utils.get_page_size(self.request)
         try:
-            # To judge whether there is next page, get LIMIT + 1
+            # To judge whether there is next page, get limit + 1
             results = api.monitor.alarmdef_list(self.request, page_offset,
-                                                LIMIT + 1)
+                                                limit + 1)
             num_results = len(results)
-            paginator = Paginator(results, LIMIT)
+            paginator = Paginator(results, limit)
             contacts = paginator.page(1)
         except EmptyPage:
             contacts = paginator.page(paginator.num_pages)
@@ -87,10 +94,10 @@ class IndexView(tables.DataTableView):
 
         context["contacts"] = contacts
 
-        if num_results < LIMIT + 1:
+        if num_results < limit + 1:
             context["page_offset"] = None
         else:
-            context["page_offset"] = page_offset + LIMIT
+            context["page_offset"] = page_offset + limit
 
         if page_offset in prev_page_stack:
             index = prev_page_stack.index(page_offset)
@@ -108,23 +115,8 @@ class IndexView(tables.DataTableView):
         return context
 
 
-class AlarmCreateView(forms.ModalFormView):
-    form_class = alarm_forms.CreateAlarmForm
-    template_name = constants.TEMPLATE_PREFIX + 'create.html'
-
-    def get_context_data(self, **kwargs):
-        context = super(AlarmCreateView, self).get_context_data(**kwargs)
-        context["cancel_url"] = self.get_success_url()
-        context["action_url"] = reverse(constants.URL_PREFIX + 'alarm_create',
-                                        args=())
-        metrics = api.monitor.metrics_list(self.request)
-
-        context["metrics"] = json.dumps(metrics)
-        return context
-
-    def get_success_url(self):
-        return reverse_lazy(constants.URL_PREFIX + 'index',
-                            args=())
+class AlarmCreateView(workflows.WorkflowView):
+    workflow_class = alarm_workflows.AlarmDefinitionWorkflow
 
 
 def transform_alarm_data(obj):
@@ -186,6 +178,8 @@ class AlarmDetailView(TemplateView):
         return transform_alarm_data(self.alarm)
 
     def get_context_data(self, **kwargs):
+        if not policy.check((('monitoring', 'monitoring:monitoring'), ), self.request):
+            raise exceptions.NotAuthorized()
         context = super(AlarmDetailView, self).get_context_data(**kwargs)
         self.get_initial()
         context["alarm"] = self.alarm
@@ -252,6 +246,8 @@ class AlarmEditView(forms.ModalFormView):
         return transform_alarm_data(self.alarm)
 
     def get_context_data(self, **kwargs):
+        if not policy.check((('monitoring', 'monitoring:monitoring'), ), self.request):
+            raise exceptions.NotAuthorized()
         context = super(AlarmEditView, self).get_context_data(**kwargs)
         id = self.kwargs['id']
         context["cancel_url"] = self.get_success_url()
