@@ -27,6 +27,9 @@ urlpatterns = patterns(
     url(r'^alarm/(?P<service>[^/]+)/$',
         views.AlarmServiceView.as_view(),
         name='alarm'),
+    url(r'^alarm/$',
+        views.AlarmServiceView.as_view(),
+        name='alarm_all'),
     url(r'^history/(?P<name>[^/]+)/(?P<id>[^/]+)$',
         views.AlarmHistoryView.as_view(),
         name='history'),
