@@ -70,11 +70,14 @@ def alarm_list_by_dimension(request, dimensions, offset=0, limit=10000,
     dimensions = dimensions.replace(" ", "")
     dimensions = dimensions.split(",")
     for item in dimensions:
-        name, value = item.split("=")
-        if name == 'metric':
-            metric = value
+        if '=' in item:
+            name, value = item.split('=')
+            if name == 'metric':
+                metric = value
+            else:
+                dim_dict[name] = value
         else:
-            dim_dict[name] = value
+            dim_dict[item] = None
     if metric:
         result = monascaclient(request).alarms.list(offset=offset, limit=limit,
                                                 metric_dimensions=dim_dict,
@@ -130,6 +133,13 @@ def alarmdef_get(request, alarm_id):
     return monascaclient(request).alarm_definitions.get(alarm_id=alarm_id)
 
 
+def alarmdef_get_by_name(request, name):
+    return monascaclient(request).alarm_definitions.list(
+        name=name,
+        limit=1
+    )
+
+
 def alarmdef_create(request, password=None, **kwargs):
     return monascaclient(request, password).alarm_definitions.create(**kwargs)
 
