@@ -61,6 +61,20 @@ class BaseNotificationMethodForm(forms.SelfHandlingForm):
                                                  max_length="512",
                                                  widget=textWidget,
                                                  help_text=_("The email/url address to notify."))
+        self.fields['period'] = forms.IntegerField(label=_("Period"),
+                                                   min_value=0,
+                                                   initial=0,
+                                                   required=required,
+                                                   help_text=_("The notification period."))
+
+    def clean_period(self):
+        '''Check to make sure period is zero unless type is WEBHOOK.
+        '''
+        data = self.cleaned_data
+        if data['type'] != constants.NotificationType.WEBHOOK and data['period'] != 0:
+            raise forms.ValidationError("Period must be zero except for type webhook.")
+
+        return data['period']
 
 
 class CreateMethodForm(BaseNotificationMethodForm):
@@ -72,7 +86,7 @@ class CreateMethodForm(BaseNotificationMethodForm):
         '''Check to make sure address is the correct format depending on the
         type of notification
         '''
-        data = super(forms.Form, self).clean()
+        data = self.cleaned_data
         if data['type'] == constants.NotificationType.EMAIL:
             constants.EMAIL_VALIDATOR(data['address'])
         elif data['type'] == constants.NotificationType.WEBHOOK:
@@ -88,7 +102,8 @@ class CreateMethodForm(BaseNotificationMethodForm):
                 request,
                 name=data['name'],
                 type=data['type'],
-                address=data['address'])
+                address=data['address'],
+                period=data['period'])
             messages.success(request,
                              _('Notification method has been created '
                                'successfully.'))
@@ -121,6 +136,7 @@ class EditMethodForm(BaseNotificationMethodForm):
             kwargs['name'] = data['name']
             kwargs['type'] = data['type']
             kwargs['address'] = data['address']
+            kwargs['period'] = data['period']
             api.monitor.notification_update(
                 request,
                 **kwargs
