@@ -14,6 +14,7 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+import base64
 import copy
 import json
 import logging
@@ -31,6 +32,8 @@ from django.views.generic import TemplateView  # noqa
 from openstack_auth import utils as auth_utils
 from openstack_dashboard import policy
 
+from horizon import exceptions
+
 from monitoring import api
 from monitoring.alarms import tables as alarm_tables
 from monitoring.config import local_settings as settings
@@ -39,29 +42,27 @@ from monitoring.overview import constants
 LOG = logging.getLogger(__name__)
 
 
+STATUS_FA_ICON_MAP = {'btn-success': "fa-check",
+                      'btn-danger': "fa-exclamation-triangle",
+                      'btn-warning': "fa-exclamation",
+                      'btn-default': "fa-question-circle"}
+
+
 def get_icon(status):
-    if status == 'chicklet-success':
-        return constants.OK_ICON
-    if status == 'chicklet-error':
-        return constants.CRITICAL_ICON
-    if status == 'chicklet-warning':
-        return constants.WARNING_ICON
-    if status == 'chicklet-unknown':
-        return constants.UNKNOWN_ICON
-    if status == 'chicklet-notfound':
-        return constants.NOTFOUND_ICON
+    return STATUS_FA_ICON_MAP.get(status,  "fa-question-circle")
 
 
 priorities = [
-    {'status': 'chicklet-success', 'severity': 'OK'},
-    {'status': 'chicklet-unknown', 'severity': 'UNDETERMINED'},
-    {'status': 'chicklet-warning', 'severity': 'LOW'},
-    {'status': 'chicklet-warning', 'severity': 'MEDIUM'},
-    {'status': 'chicklet-warning', 'severity': 'HIGH'},
-    {'status': 'chicklet-error', 'severity': 'CRITICAL'},
+    {'status': 'btn-success', 'severity': 'OK'},
+    {'status': 'btn-default', 'severity': 'UNDETERMINED'},
+    {'status': 'btn-warning', 'severity': 'LOW'},
+    {'status': 'btn-warning', 'severity': 'MEDIUM'},
+    {'status': 'btn-warning', 'severity': 'HIGH'},
+    {'status': 'btn-danger', 'severity': 'CRITICAL'},
 ]
 index_by_severity = {d['severity']: i for i, d in enumerate(priorities)}
 
+
 def get_dashboard_links(request):
     #
     # GRAFANA_LINKS is a list of dictionaries, but can either
@@ -77,7 +78,7 @@ def get_dashboard_links(request):
     #
     # See examples of both in local_settings.py
     #
-    non_project_keys = {'fileName','title'}
+    non_project_keys = {'fileName', 'title'}
     try:
         for project_link in settings.DASHBOARDS:
             key = project_link.keys()[0]
@@ -111,6 +112,7 @@ def get_dashboard_links(request):
     #
     return settings.DASHBOARDS
 
+
 def get_monitoring_services(request):
     #
     # GRAFANA_LINKS is a list of dictionaries, but can either
@@ -160,6 +162,7 @@ def get_monitoring_services(request):
     #
     return settings.MONITORING_SERVICES
 
+
 def show_by_dimension(data, dim_name):
     if 'dimensions' in data['metrics'][0]:
         dimensions = data['metrics'][0]['dimensions']
@@ -174,7 +177,7 @@ def get_status(alarms):
     status_index = 0
     for a in alarms:
         severity = alarm_tables.show_severity(a)
-        severity_index = index_by_severity[severity]
+        severity_index = index_by_severity.get(severity, None)
         status_index = max(status_index, severity_index)
     return priorities[status_index]['status']
 
@@ -203,9 +206,12 @@ def generate_status(request):
                     group_alarms.append(a)
             services = []
             for group, group_alarms in alarms_by_group.items():
+                name = '%s=%s' % (row['groupBy'], group)
+                # Encode as base64url to be able to include '/'
+                name = 'b64:' + base64.urlsafe_b64encode(name)
                 service = {
                     'display': group,
-                    'name': "%s=%s" % (row['groupBy'], group),
+                    'name': name,
                     'class': get_status(group_alarms)
                 }
                 service['icon'] = get_icon(service['class'])
@@ -224,6 +230,8 @@ class IndexView(TemplateView):
     template_name = constants.TEMPLATE_PREFIX + 'index.html'
 
     def get_context_data(self, **kwargs):
+        if not policy.check((('monitoring', 'monitoring:monitoring'), ), self.request):
+            raise exceptions.NotAuthorized()
         context = super(IndexView, self).get_context_data(**kwargs)
         try:
             region = self.request.user.services_region
@@ -270,7 +278,7 @@ class MonascaProxyView(TemplateView):
             # dimension for all metrics (mini-mon for one).
             #
             if 'region' in dim_dict and dim_dict['region'] == 'INJECT_REGION':
-                 dim_dict['region'] = self.request.user.services_region
+                dim_dict['region'] = self.request.user.services_region
             req_kwargs['dimensions'] = dim_dict
 
         return req_kwargs
